@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-__version__ = '2.3.7'
+__version__ = '2.3.8'
 
 # patch settings 
 try:
@@ -7,7 +7,7 @@ try:
     if 'cms' in settings.INSTALLED_APPS:
         from conf import patch_settings
         patch_settings()
-except: # pragma: no cover
+except ImportError: # pragma: no cover
     """
     This exception means that either the application is being built, or is
     otherwise installed improperly. Both make running patch_settings
