@@ -2,7 +2,7 @@
 from cms.apphook_pool import apphook_pool
 from cms.forms.widgets import UserSelectAdminWidget
 from cms.models import (Page, PagePermission, PageUser, ACCESS_PAGE, 
-    PageUserGroup)
+    PageUserGroup, titlemodels)
 from cms.utils.mail import mail_page_user_change
 from cms.utils.page import is_valid_page_slug
 from cms.utils.page_resolver import get_page_from_path, is_valid_url
@@ -92,10 +92,7 @@ class PageAddForm(forms.ModelForm):
         
     def clean(self):
         cleaned_data = self.cleaned_data
-        if 'slug' in cleaned_data.keys():
-            slug = cleaned_data['slug']
-        else:
-            slug = ""
+        slug = cleaned_data.get('slug', '')
         
         page = self.instance
         lang = cleaned_data.get('language', None)
@@ -116,22 +113,26 @@ class PageAddForm(forms.ModelForm):
         if site and not is_valid_page_slug(page, parent, lang, slug, site):
             self._errors['slug'] = ErrorList([_('Another page with this slug already exists')])
             del cleaned_data['slug']
-        if self.cleaned_data['published'] and page.title_set.count():
+        if self.cleaned_data.get('published') and page.title_set.count():
             #Check for titles attached to the page makes sense only because
             #AdminFormsTests.test_clean_overwrite_url validates the form with when no page instance available
             #Looks like just a theoretical corner case
-            title = page.get_title_obj(lang)
-            if title:
+            try:
+                title = page.get_title_obj(lang, fallback=False)
+            except titlemodels.Title.DoesNotExist:
+                title = None
+            if title and not isinstance(title, titlemodels.EmptyTitle) and slug:
                 oldslug = title.slug
-                title.slug = self.cleaned_data['slug']
+                title.slug = slug
                 title.save()
                 try:
                     is_valid_url(title.path,page)
                 except ValidationError,e:
                     title.slug = oldslug
                     title.save()
-                    del cleaned_data['published']
-                    self._errors['published'] = ErrorList(e.messages)
+                    if 'slug' in cleaned_data:
+                        del cleaned_data['slug']
+                    self._errors['slug'] = ErrorList(e.messages)
         return cleaned_data
     
     def clean_slug(self):
