@@ -6,9 +6,9 @@ from cms.models.placeholdermodel import Placeholder
 from cms.models.pluginmodel import CMSPlugin
 from cms.publisher.errors import MpttPublisherCantPublish
 from cms.utils import i18n, urlutils, page as page_utils
+from cms.utils import timezone
 from cms.utils.copy_plugins import copy_plugins_to
 from cms.utils.helpers import reversion_register
-from datetime import datetime
 from django.conf import settings
 from django.contrib.sites.models import Site
 from django.core.exceptions import ObjectDoesNotExist
@@ -348,7 +348,7 @@ class Page(MPTTModel):
 
         # if the page is published we set the publish date if not set yet.
         if self.publication_date is None and self.published:
-            self.publication_date = datetime.now()
+            self.publication_date = timezone.now()
 
         if self.reverse_id == "":
             self.reverse_id = None
@@ -546,6 +546,8 @@ class Page(MPTTModel):
     def get_title_obj(self, language=None, fallback=True, version_id=None, force_reload=False):
         """Helper function for accessing wanted / current title.
         If wanted title doesn't exists, EmptyTitle instance will be returned.
+        If fallback=False is used, titlemodels.Title.DoesNotExist will be raised
+        when a language does not exist.
         """
 
         language = self._get_title_cache(language, fallback, version_id, force_reload)
