@@ -26,8 +26,8 @@ class File(CMSPlugin):
     # CMS_ICON_EXTENSIONS and CMS_ICON_PATH are assumed to be plugin-specific, and not included in cms.settings
     # -- they are therefore imported from django.conf.settings
     ICON_EXTENSIONS = getattr(settings, "CMS_FILE_ICON_EXTENSIONS", ('gif', 'png'))
-    ICON_PATH = getattr(settings, "CMS_FILE_ICON_PATH", os.path.join(settings.CMS_MEDIA_ROOT, "images", "file_icons"))
-    ICON_URL = getattr(settings, "CMS_FILE_ICON_URL", "%s%s/%s/" % (settings.CMS_MEDIA_URL, "images", "file_icons"))
+    ICON_PATH = getattr(settings, "CMS_FILE_ICON_PATH", os.path.join(settings.STATIC_ROOT, "cms", "images", "file_icons"))
+    ICON_URL = getattr(settings, "CMS_FILE_ICON_URL", "%s%s/%s/%s/" % (settings.STATIC_URL, "cms", "images", "file_icons"))
         
     def get_icon_url(self):
         path_base = os.path.join(self.ICON_PATH, self.get_ext())
