@@ -12,21 +12,20 @@ class PicturePlugin(CMSPluginBase):
     
     def render(self, context, instance, placeholder):
         if instance.url:
-            link = settings.dbgettext(instance.url)
+            link = instance.url
         elif instance.page_link:
             link = instance.page_link.get_absolute_url()
         else:
             link = ""
-        instance.alt = settings.dbgettext(instance.alt)
         context.update({
-            'picture':instance,
-            'link':link, 
-            'placeholder':placeholder
+            'picture': instance,
+            'link': link, 
+            'placeholder': placeholder
         })
         return context 
     
     def icon_src(self, instance):
         # TODO - possibly use 'instance' and provide a thumbnail image
-        return settings.CMS_MEDIA_URL + u"images/plugins/image.png"
+        return settings.STATIC_URL + u"cms/images/plugins/image.png"
  
 plugin_pool.register_plugin(PicturePlugin)
