@@ -68,7 +68,7 @@
 					url: "copy-plugins/", dataType: "html", type: "POST",
 					data: { page_id: page_id, placeholder: placeholder, copy_from: copy_from_language, language: to_language },
 					success: function(data) {
-						ul_list.append(data);
+						ul_list.empty().append(data);
 						setclickfunctions();
 					},
 					error: function(xhr) {
