@@ -3,15 +3,23 @@ from django.conf import settings
 from django.http import HttpResponse
 from django.shortcuts import render_to_response
 from django.template.context import RequestContext
-
+from django.utils import simplejson
 from django.contrib.sites.models import Site
 
-from cms.models.pagemodel import Page
-from cms.models.permissionmodels import GlobalPagePermission
+from cms.models import Page
 from cms.utils import permissions, moderator, get_language_from_request
+from cms.utils.permissions import has_global_page_permission
 
 NOT_FOUND_RESPONSE = "NotFound"
 
+def jsonify_request(response):
+    """ Turn any response in a 200 response to let jQuery code handle it nicely.
+        Response contains a json object with the following attributes:
+         * status: original response status code
+         * content: original response content
+    """
+    return HttpResponse(simplejson.dumps({'status':response.status_code,'content':response.content}),
+                                content_type="application/json")
 
 def get_admin_menu_item_context(request, page, filtered=False):
     """
@@ -42,9 +50,9 @@ def get_admin_menu_item_context(request, page, filtered=False):
     has_add_on_same_level_permission = False
     opts = Page._meta
     if settings.CMS_PERMISSION:
-        if (request.user.has_perm(opts.app_label + '.' + opts.get_add_permission()) and
-                GlobalPagePermission.objects.with_user(request.user).filter(can_add=True, sites__in=[page.site_id])):
-                has_add_on_same_level_permission = True
+        perms = has_global_page_permission(request, page.site_id, can_add=True)
+        if (request.user.has_perm(opts.app_label + '.' + opts.get_add_permission()) and perms):
+            has_add_on_same_level_permission = True
         
     if not has_add_on_same_level_permission and page.parent_id:
         has_add_on_same_level_permission = permissions.has_generic_permission(page.parent_id, request.user, "add", page.site)
@@ -96,4 +104,5 @@ def render_admin_menu_item(request, page, template=None):
     
     filtered = 'filtered' in request.REQUEST
     context.update(get_admin_menu_item_context(request, page, filtered))
-    return render_to_response(template, context)
+    # add mimetype to help out IE
+    return render_to_response(template, context, mimetype="text/html; charset=utf-8")
